#       m   
#      u    rowfactory.py - Fri Jun 15 15:57 CEST 2012
#  SQLite   exposes columns as row attributes
#    d      part of sqmediumlite
#   e       copyright (C): nobody
#  m        

"""
Custom version of the Row class from the standard Python
sqlite3 module (Pysqlite):
    http://docs.python.org/library/sqlite3.html#sqlite3.Connection.row_factory
A seperate version is included to to be used with APSW:
    http://apidoc.apsw.googlecode.com/hg/execution.html#row-tracer
Differences with the standard Row class are:
- columns can be accessed as attributes (PL/SQL style)
- can be passed as bind variables (dict) to new queries
- table alias is eventually  stripped: tab.colname -> colname
- does NOT support get column by position.
"""

class Row (dict):
    " row_factory for standard Python sqlite3 (Pysqlite) "
    def __init__ (self, cur, values):
        dict.__init__ (self, zip (
                (t[0] [t[0].find ('.') + 1:].lower ()
                    for t in cur.description),
                values
                ))
    def __getitem__ (self, k): return dict.__getitem__ (self, k.lower())
    def __setitem__ (self, k, v): return dict.__setitem__ (self, k.lower(), v)
    __getattr__ = __getitem__
    __setattr__ = __setitem__

class apswRow (dict):
    " argument for setrowtrace in APSW "
    def __init__ (self, cur, values):
        dict.__init__ (self, zip (
                (t[0] [t[0].find ('.') + 1:].lower ()
                    for t in cur.getdescription ()),
                values
                ))
    def __getitem__ (self, k): return dict.__getitem__ (self, k.lower())
    def __setitem__ (self, k, v): return dict.__setitem__ (self, k.lower(), v)
    __getattr__ = __getitem__
    __setattr__ = __setitem__
